IndexBlock

Struct IndexBlock 

pub struct IndexBlock<T> { /* private fields */ }
IndexVec allows to store h3index in compressed form.

The main purpose of this is to allow having seldom used data in memory without it occupying too much space. This sacrifices a bit of speed when accessing the data.

The order if the h3indexes in the block is not changed, so - for example - continuous paths of h3 edges can be stored without them becoming shuffled.

The compression is done using run-length-encoding (RLE). To improve the compression ratio the bytes of all contained h3indexes are grouped by their position in the u64 of the h3index. For spatially close h3index this results in a quite good compression ratio as many bytes are common over many h3indexes. As an example: a k-ring with k=50 and 7651 cells compresses from 61kb to around 7.6kb.

Implementations

Source

impl<T> IndexBlock<T>
where T: Index,

pub const fn len(&self) -> usize

pub const fn is_empty(&self) -> bool

pub fn contains(&self, index: &T) -> Result<bool, Error>

check if index is contained in this IndexBlock.

This method avoids decompressing the whole block at once and instead only decompresses single bytes while traversing the contained indexes.

pub const fn size_of_uncompressed(&self) -> usize

The size of the inner data when it would be stored in a simple Vec

pub const fn size_of_compressed(&self) -> usize

pub fn iter_uncompressed(&self) -> Result<OwningDecompressedIter<'_, T>, Error>

returns an iterator over the decompressed decompressed contents of the IndexBlock.

Useful for situations where only one or few decompressions are done. When many blocks are decompressed using the Decompressor is more efficient as the decompression buffer needs to be allocated only once.